@@ -270,7 +270,8 @@ stfio::filetype stfio::importBiosigFile(const std::string &fName, Recording &Ret
     Desc += std::string ("\nUser specified Annotations:\n")+annotationTableDesc;
 
     ReturnData.SetFileDescription(Desc);
-    //ReturnData.SetGlobalSectionDescription(Desc);
+    // hdr->AS.bci2000 is an alias to hdr->AS.fpulse, which available only in libbiosig v1.6.0 and later
+    if (hdr->AS.bci2000) ReturnData.SetGlobalSectionDescription(hdr->AS.bci2000 + '\0');
 
     ReturnData.SetXScale(1000.0/biosig_get_samplerate(hdr));
     ReturnData.SetXUnits("ms");
@@ -497,7 +498,8 @@ stfio::filetype stfio::importBiosigFile(const std::string &fName, Recording &Ret
         }
     }
     ReturnData.SetFileDescription(Desc);
-    //ReturnData.SetGlobalSectionDescription(Desc);
+    // hdr->AS.bci2000 is an alias to hdr->AS.fpulse, which available only in libbiosig v1.6.0 or later
+    if (hdr->AS.bci2000) ReturnData.SetGlobalSectionDescription(hdr->AS.bci2000 + '\0');
 
     ReturnData.SetXScale(1000.0/hdr->SampleRate);
     ReturnData.SetXUnits("ms");
