@@ -398,18 +398,22 @@ wxStfBatchDlg::wxStfBatchDlg(wxWindow* parent, int id, wxString title, wxPoint p
     batchOptions.push_back( BatchOption( wxT("Base"), true, id_base ) );
     batchOptions.push_back( BatchOption( wxT("Base SD"), false, id_basesd ) );
     batchOptions.push_back( BatchOption( wxT("Threshold"), true, id_threshold ) );
+    batchOptions.push_back( BatchOption( wxT("time of slope threshold crossing"), false, id_slopethresholdtime ) );
     batchOptions.push_back( BatchOption( wxT("Peak (from 0)"), true, id_peakzero ) );
     batchOptions.push_back( BatchOption( wxT("Peak (from base)"), true, id_peakbase ) );
     batchOptions.push_back( BatchOption( wxT("Peak (from threshold)"), true, id_peakthreshold ) );
+    batchOptions.push_back( BatchOption( wxT("Peak time"), true, id_peaktime ) );
     batchOptions.push_back( BatchOption( wxT("Lo-Hi% risetime"), false, id_rtLoHi ) );
     batchOptions.push_back( BatchOption( wxT("inner risetime"), false, id_innerLoHi ) );
     batchOptions.push_back( BatchOption( wxT("outer risetime"), false, id_outerLoHi ) );
-    batchOptions.push_back( BatchOption( wxT("Half duration"), false, id_t50 ) );
-    batchOptions.push_back( BatchOption( wxT("Max Slopes"), false, id_slopes ) );
+    batchOptions.push_back( BatchOption( wxT("Half amplitude duration"), false, id_t50 ) );
+    batchOptions.push_back( BatchOption( wxT("start and end time of half amplitude"), false, id_t50se ) );
+    batchOptions.push_back( BatchOption( wxT("Max slopes"), false, id_slopes ) );
+    batchOptions.push_back( BatchOption( wxT("Max slope times"), false, id_slopetimes ) );
     batchOptions.push_back( BatchOption( wxT("Latencies"), false, id_latencies ) );
     batchOptions.push_back( BatchOption( wxT("Fit results"), false, id_fit ) );
 #ifdef WITH_PSLOPE
-    batchOptions.push_back( BatchOption( wxT("Slopes"), false, id_pslopes ) );
+    batchOptions.push_back( BatchOption( wxT("pSlope"), false, id_pslopes ) );
 #endif
     batchOptions.push_back( BatchOption( wxT("Threshold crossings"), false, id_crossings ) );
     std::vector<BatchOption>::const_iterator bo_it;
@@ -425,7 +429,7 @@ wxStfBatchDlg::wxStfBatchDlg(wxWindow* parent, int id, wxString title, wxPoint p
         }
     };
     m_checkList =
-        new wxCheckListBox( this, wxID_ANY, wxDefaultPosition, wxSize(180,350), 
+        new wxCheckListBox( this, wxID_ANY, wxDefaultPosition, wxSize(280,350),
                             checkListChoices.size(), &checkListChoices[0], 0 );
     for (bo_it = batchOptions.begin(); bo_it != batchOptions.end(); ++bo_it) {
         m_checkList->Check(bo_it->index, wxGetApp().wxGetProfileInt( wxT("Batch Dialog"), bo_it->label, bo_it->selection) );
